@@ -26,11 +26,12 @@
 #include <plasma/theme.h>
 
 
-Tooltip::Tooltip(QString text) : QWidget()
+Tooltip::Tooltip(const QString &text)
+    : QWidget()
 {
     setAttribute(Qt::WA_TranslucentBackground);
     setAttribute(Qt::WA_TransparentForMouseEvents);
-    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint );
+    setWindowFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
 
     setColors();
     connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(setColors()));
@@ -50,31 +51,31 @@ Tooltip::Tooltip(QString text) : QWidget()
     connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(updateMask()));
 }
 
-Tooltip::~Tooltip() {
+Tooltip::~Tooltip()
+{
 
 }
 
-void Tooltip::setColors(){
+void Tooltip::setColors()
+{
     QPalette pal = palette();
     pal.setColor(backgroundRole(), Qt::transparent);
     pal.setColor(QPalette::WindowText, Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor));
     setPalette(pal);
 }
 
-void Tooltip::setText(QString text) {
+void Tooltip::setText(QString text)
+{
     label->setText(text);
 }
 
-void Tooltip::resizeEvent(QResizeEvent *event) {
+void Tooltip::resizeEvent(QResizeEvent *event)
+{
     QSize size = event->size();
     QWidget::resize(size);
-    setFont(QFont ( "Helvetica", qMin(size.height(),size.width()) / 3) );
+    setFont(QFont("Helvetica", qMin(size.height(), size.width()) / 3));
     frame->resizeFrame(size);
     updateMask();
-    /*
-    QImage img( size, QImage::Format_Mono);
-    img.fill(0);
-    setMask(QBitmap::fromImage(img, Qt::MonoOnly));*/
 }
 
 void Tooltip::showEvent(QShowEvent * event)
@@ -87,7 +88,7 @@ void Tooltip::updateMask()
 {
     const bool translucency = Plasma::Theme::defaultTheme()->windowTranslucencyEnabled();
     Plasma::WindowEffects::enableBlurBehind(winId(), translucency,
-                                    translucency ? frame->mask() : QRegion());
+                                            translucency ? frame->mask() : QRegion());
     if (translucency) {
         clearMask();
     } else {
@@ -95,7 +96,8 @@ void Tooltip::updateMask()
     }
 }
 
-void Tooltip::paintEvent ( QPaintEvent * event ){
+void Tooltip::paintEvent(QPaintEvent * event)
+{
     QPainter painter(this);
     painter.setRenderHint(QPainter::SmoothPixmapTransform);
     painter.setRenderHint(QPainter::Antialiasing);
@@ -104,12 +106,5 @@ void Tooltip::paintEvent ( QPaintEvent * event ){
     frame->paintFrame(&painter, event->rect());
 }
 
-/*bool Tooltip::paintEvent(QPaintEvent *event)
-{
-    if (event->type() == QEvent::Paint) {
-	QPainter painter(this);
+#include "tooltip.moc"
 
-    }
-
-    return QWidget::event(event);
-}*/
